pub struct RawTransaction { /* private fields */ }Expand description
RawTransaction is the portion of a transaction that a client signs.
Implementations
Sourceimpl RawTransaction
impl RawTransaction
Sourcepub fn new(
sender: AccountAddress,
payload: TransactionPayload,
expiration_timestamp_secs: u64,
chain_id: ChainId,
) -> Self
pub fn new( sender: AccountAddress, payload: TransactionPayload, expiration_timestamp_secs: u64, chain_id: ChainId, ) -> Self
Create a new RawTransaction with a payload.
It can be either to publish a module, to execute a script, or to issue a writeset transaction.
pub fn new_pivot_decision( sender: AccountAddress, pivot_decision: PivotBlockDecision, chain_id: ChainId, ) -> Self
pub fn new_election( sender: AccountAddress, election_payload: ElectionPayload, chain_id: ChainId, ) -> Self
pub fn new_dispute( sender: AccountAddress, dispute_payload: DisputePayload, ) -> Self
pub fn new_retire(sender: AccountAddress, retire_payload: RetirePayload) -> Self
pub fn from_staking_event( staking_event: &StakingEvent, sender: AccountAddress, ) -> Result<Self>
Sourcepub fn sign(
self,
private_key: &ConsensusPrivateKey,
) -> Result<SignatureCheckedTransaction>
pub fn sign( self, private_key: &ConsensusPrivateKey, ) -> Result<SignatureCheckedTransaction>
Signs the given RawTransaction. Note that this consumes the
RawTransaction and turns it into a SignatureCheckedTransaction.
For a transaction that has just been signed, its signature is expected to be valid.
pub fn into_payload(self) -> TransactionPayload
Sourcepub fn sender(&self) -> AccountAddress
pub fn sender(&self) -> AccountAddress
Return the sender of this transaction.